@@ -1,5 +1,5 @@
 /*
- *  $Id: consent.c,v 5.92 2002-10-12 20:07:43-07 bryan Exp $
+ *  $Id: consent.c,v 5.101 2003-03-09 15:51:15-08 bryan Exp $
  *
  *  Copyright conserver.com, 2000
  *
@@ -94,7 +94,7 @@ BAUD baud[] = {
 /* find a baud rate for the string "9600x" -> B9600			(ksb)
  */
 BAUD *
-#if USE_ANSI_PROTO
+#if PROTOTYPES
 FindBaud(char *pcMode)
 #else
 FindBaud(pcMode)
@@ -151,7 +151,7 @@ PARITY parity[] = {
 /* find a parity on the end of a baud "9600even" -> EVEN		(ksb)
  */
 PARITY *
-#if USE_ANSI_PROTO
+#if PROTOTYPES
 FindParity(char *pcMode)
 #else
 FindParity(pcMode)
@@ -180,7 +180,7 @@ FindParity(pcMode)
 /* setup a tty device							(ksb)
  */
 static int
-#if USE_ANSI_PROTO
+#if PROTOTYPES
 TtyDev(CONSENT * pCE)
 #else
 TtyDev(pCE)
@@ -193,7 +193,8 @@ TtyDev(pCE)
     /* here we should fstat for `read-only' checks
      */
     if (-1 == fstat(pCE->fdtty, &stPerm)) {
-	Error("fstat: %s: %s", pCE->dfile.string, strerror(errno));
+	Error("[%s] fstat(%s(%d)): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
     } else if (0 == (stPerm.st_mode & 0222)) {
 	/* any device that is read-only we won't write to
 	 */
@@ -204,8 +205,8 @@ TtyDev(pCE)
      * Get terminal attributes
      */
     if (-1 == tcgetattr(pCE->fdtty, &termp)) {
-	Error("tcgetattr: %s(%d): %s", pCE->dfile.string, pCE->fdtty,
-	      strerror(errno));
+	Error("[%s] tcgetattr(%s(%d)): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
 	return -1;
     }
 
@@ -234,13 +235,13 @@ TtyDev(pCE)
     termp.c_cc[VTIME] = 1;
 
     if (-1 == cfsetospeed(&termp, pCE->pbaud->irate)) {
-	Error("cfsetospeed: %s(%d): %s", pCE->dfile.string, pCE->fdtty,
-	      strerror(errno));
+	Error("[%s] cfsetospeed(%s(%d)): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
 	return -1;
     }
     if (-1 == cfsetispeed(&termp, pCE->pbaud->irate)) {
-	Error("cfsetispeed: %s(%d): %s", pCE->dfile.string, pCE->fdtty,
-	      strerror(errno));
+	Error("[%s] cfsetispeed(%s(%d)): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
 	return -1;
     }
 
@@ -248,8 +249,8 @@ TtyDev(pCE)
      * Set terminal attributes
      */
     if (-1 == tcsetattr(pCE->fdtty, TCSADRAIN, &termp)) {
-	Error("tcsetattr: %s(%d): %s", pCE->dfile.string, pCE->fdtty,
-	      strerror(errno));
+	Error("[%s] tcsetattr(%s(%d),TCSADRAIN): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
 	return -1;
     }
 # if HAVE_STROPTS_H
@@ -257,7 +258,7 @@ TtyDev(pCE)
      * eat all the streams modules upto and including ttcompat
      */
     while (ioctl(pCE->fdtty, I_FIND, "ttcompat") == 1) {
-	(void)ioctl(pCE->fdtty, I_POP, 0);
+	ioctl(pCE->fdtty, I_POP, 0);
     }
 # endif
     pCE->fup = 1;
@@ -271,7 +272,7 @@ TtyDev(pCE)
 /* setup a tty device							(ksb)
  */
 static int
-#if USE_ANSI_PROTO
+#if PROTOTYPES
 TtyDev(CONSENT * pCE)
 #else
 TtyDev(pCE)
@@ -286,7 +287,8 @@ TtyDev(pCE)
     /* here we should fstat for `read-only' checks
      */
     if (-1 == fstat(pCE->fdtty, &stPerm)) {
-	Error("fstat: %s: %s", pCE->dfile.string, strerror(errno));
+	Error("[%s] fstat(%s(%d)): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
     } else if (0 == (stPerm.st_mode & 0222)) {
 	/* any device that is read-only we won't write to
 	 */
@@ -294,7 +296,8 @@ TtyDev(pCE)
     }
 #  if defined(TIOCSSOFTCAR)
     if (-1 == ioctl(pCE->fdtty, TIOCSSOFTCAR, &fSoftcar)) {
-	Error("softcar: %d: %s", pCE->fdtty, strerror(errno));
+	Error("[%s] ioctl(%s(%d),TIOCSSOFTCAR): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
 	return -1;
     }
 #  endif
@@ -302,8 +305,8 @@ TtyDev(pCE)
     /* stty 9600 raw cs7
      */
     if (-1 == ioctl(pCE->fdtty, TIOCGETP, (char *)&sty)) {
-	Error("ioctl1: %s(%d): %s", pCE->dfile.string, pCE->fdtty,
-	      strerror(errno));
+	Error("[%s] ioctl(%s(%d),TIOCGETP): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
 	return -1;
     }
     sty.sg_flags &= ~(ECHO | CRMOD | pCE->pparity->iclr);
@@ -313,7 +316,8 @@ TtyDev(pCE)
     sty.sg_ispeed = pCE->pbaud->irate;
     sty.sg_ospeed = pCE->pbaud->irate;
     if (-1 == ioctl(pCE->fdtty, TIOCSETP, (char *)&sty)) {
-	Error("ioctl2: %d: %s", pCE->fdtty, strerror(errno));
+	Error("[%s] ioctl(%s(%d),TIOCSETP): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
 	return -1;
     }
 
@@ -321,7 +325,8 @@ TtyDev(pCE)
      * (in cbreak mode we may not need to this... but we do)
      */
     if (-1 == ioctl(pCE->fdtty, TIOCGETC, (char *)&m_tchars)) {
-	Error("ioctl3: %d: %s", pCE->fdtty, strerror(errno));
+	Error("[%s] ioctl(%s(%d),TIOCGETC): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
 	return -1;
     }
     m_tchars.t_intrc = -1;
@@ -331,11 +336,13 @@ TtyDev(pCE)
     m_tchars.t_eofc = -1;
     m_tchars.t_brkc = -1;
     if (-1 == ioctl(pCE->fdtty, TIOCSETC, (char *)&m_tchars)) {
-	Error("ioctl4: %d: %s", pCE->fdtty, strerror(errno));
+	Error("[%s] ioctl(%s(%d),TIOCSETC): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
 	return -1;
     }
     if (-1 == ioctl(pCE->fdtty, TIOCGLTC, (char *)&m_ltchars)) {
-	Error("ioctl5: %d: %s", pCE->fdtty, strerror(errno));
+	Error("[%s] ioctl(%s(%d),TIOCGLTC): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
 	return -1;
     }
     m_ltchars.t_werasc = -1;
@@ -344,7 +351,8 @@ TtyDev(pCE)
     m_ltchars.t_suspc = -1;
     m_ltchars.t_dsuspc = -1;
     if (-1 == ioctl(pCE->fdtty, TIOCSLTC, (char *)&m_ltchars)) {
-	Error("ioctl6: %d: %s", pCE->fdtty, strerror(errno));
+	Error("[%s] ioctl(%s(%d),TIOCSLTC): %s", pCE->server.string,
+	      pCE->dfile.string, pCE->fdtty, strerror(errno));
 	return -1;
     }
 #  if HAVE_STROPTS_H
@@ -365,7 +373,7 @@ TtyDev(pCE)
 /* setup a virtual device						(ksb)
  */
 static int
-#if USE_ANSI_PROTO
+#if PROTOTYPES
 VirtDev(CONSENT * pCE)
 #else
 VirtDev(pCE)
@@ -381,12 +389,13 @@ VirtDev(pCE)
     struct ltchars m_ltchars;
 #  endif
 # endif
-    int i, iNewGrp;
+    int i;
+    pid_t iNewGrp;
     extern char **environ;
     char *pcShell, **ppcArgv;
 
-    (void)fflush(stdout);
-    (void)fflush(stderr);
+    fflush(stdout);
+    fflush(stderr);
 
     switch (pCE->ipid = fork()) {
 	case -1:
@@ -395,35 +404,34 @@ VirtDev(pCE)
 	    thepid = getpid();
 	    break;
 	default:
-	    if (fVerbose)
-		Error("%s has pid %d on %s", pCE->server.string, pCE->ipid,
-		      pCE->acslave.string);
-	    (void)fflush(stderr);
+	    Verbose("[%s] pid %lu on %s", pCE->server.string, pCE->ipid,
+		    pCE->acslave.string);
+	    fflush(stderr);
 	    pCE->fup = 1;
 	    return 0;
     }
 
     /* put the signals back that we ignore (trapped auto-reset to default)
      */
-    simpleSignal(SIGQUIT, SIG_DFL);
-    simpleSignal(SIGINT, SIG_DFL);
-    simpleSignal(SIGPIPE, SIG_DFL);
+    SimpleSignal(SIGQUIT, SIG_DFL);
+    SimpleSignal(SIGINT, SIG_DFL);
+    SimpleSignal(SIGPIPE, SIG_DFL);
 #if defined(SIGTTOU)
-    simpleSignal(SIGTTOU, SIG_DFL);
+    SimpleSignal(SIGTTOU, SIG_DFL);
 #endif
 #if defined(SIGTTIN)
-    simpleSignal(SIGTTIN, SIG_DFL);
+    SimpleSignal(SIGTTIN, SIG_DFL);
 #endif
 #if defined(SIGTSTP)
-    simpleSignal(SIGTSTP, SIG_DFL);
+    SimpleSignal(SIGTSTP, SIG_DFL);
 #endif
 #if defined(SIGPOLL)
-    simpleSignal(SIGPOLL, SIG_DFL);
+    SimpleSignal(SIGPOLL, SIG_DFL);
 #endif
 
     /* setup new process with clean filew descriptors
      */
-    i = cmaxfiles();
+    i = GetMaxFiles();
     for ( /* i above */ ; --i > 2;) {
 	close(i);
     }
@@ -435,7 +443,7 @@ VirtDev(pCE)
 # if HAVE_SETSID
     iNewGrp = setsid();
     if (-1 == iNewGrp) {
-	Error("%s: setsid: %s", pCE->server.string, strerror(errno));
+	Error("[%s] setsid(): %s", pCE->server.string, strerror(errno));
 	iNewGrp = getpid();
     }
 # else
@@ -443,7 +451,7 @@ VirtDev(pCE)
 # endif
 
     if (0 != open(pCE->acslave.string, O_RDWR, 0) || 1 != dup(0)) {
-	Error("%s: fd sync error", pCE->server.string);
+	Error("[%s] fd sync error", pCE->server.string);
 	exit(EX_UNAVAILABLE);
     }
 # if HAVE_STROPTS_H  && !defined(_AIX)
@@ -451,13 +459,13 @@ VirtDev(pCE)
      * under PTX (others?) we have to push the compatibility
      * streams modules `ptem', `ld', and `ttcompat'
      */
-    Debug(1, "Pushing ptemp onto pseudo-terminal");
-    (void)ioctl(0, I_PUSH, "ptem");
-    Debug(1, "Pushing ldterm onto pseudo-terminal");
-    (void)ioctl(0, I_PUSH, "ldterm");
-    Debug(1, "Pushing ttcompat onto pseudo-terminal");
-    (void)ioctl(0, I_PUSH, "ttcompat");
-    Debug(1, "Done pushing modules onto pseudo-terminal");
+    Debug(1, "VirtDev(): pushing ptemp onto pseudo-terminal");
+    ioctl(0, I_PUSH, "ptem");
+    Debug(1, "VirtDev(): pushing ldterm onto pseudo-terminal");
+    ioctl(0, I_PUSH, "ldterm");
+    Debug(1, "VirtDev(): pushing ttcompat onto pseudo-terminal");
+    ioctl(0, I_PUSH, "ttcompat");
+    Debug(1, "VirtDev(): done pushing modules onto pseudo-terminal");
 # endif
 
 # if HAVE_TERMIOS_H
@@ -467,7 +475,8 @@ VirtDev(pCE)
     if (0 != ioctl(0, TCGETS, &n_tio))
 #  endif
     {
-	Error("ioctl: getsw: %s", strerror(errno));
+	Error("[%s] ioctl(0,TCGETS): %s", pCE->server.string,
+	      strerror(errno));
 	exit(EX_UNAVAILABLE);
     }
     n_tio.c_iflag &= ~(IGNCR | IUCLC);
@@ -493,7 +502,8 @@ VirtDev(pCE)
     if (0 != ioctl(0, TCSETS, &n_tio))
 #  endif
     {
-	Error("getattr: %s", strerror(errno));
+	Error("[%s] ioctl(0,TCSETS): %s", pCE->server.string,
+	      strerror(errno));
 	exit(EX_UNAVAILABLE);
     }
 
@@ -502,7 +512,8 @@ VirtDev(pCE)
     /* stty 9600 raw cs7
      */
     if (-1 == ioctl(0, TIOCGETP, (char *)&sty)) {
-	Error("ioctl1: %s: %s", pCE->fdtty, strerror(errno));
+	Error("[%s] ioctl(0,TIOCGETP): %s", pCE->server.string,
+	      strerror(errno));
 	exit(EX_UNAVAILABLE);
     }
     sty.sg_flags &= ~(CBREAK | TANDEM | pCE->pparity->iclr);
@@ -512,7 +523,8 @@ VirtDev(pCE)
     sty.sg_ispeed = pCE->pbaud->irate;
     sty.sg_ospeed = pCE->pbaud->irate;
     if (-1 == ioctl(0, TIOCSETP, (char *)&sty)) {
-	Error("ioctl2: %s", strerror(errno));
+	Error("[%s] ioctl(0,TIOCSETP): %s", pCE->server.string,
+	      strerror(errno));
 	exit(EX_UNAVAILABLE);
     }
 
@@ -520,7 +532,8 @@ VirtDev(pCE)
      * (in cbreak mode we may not need to this... but we do)
      */
     if (-1 == ioctl(0, TIOCGETC, (char *)&m_tchars)) {
-	Error("ioctl3: %s", strerror(errno));
+	Error("[%s] ioctl(0,TIOCGETC): %s", pCE->server.string,
+	      strerror(errno));
 	exit(EX_UNAVAILABLE);
     }
     m_tchars.t_intrc = '\003';
@@ -530,11 +543,13 @@ VirtDev(pCE)
     m_tchars.t_eofc = '\004';
     m_tchars.t_brkc = '\033';
     if (-1 == ioctl(0, TIOCSETC, (char *)&m_tchars)) {
-	Error("ioctl4: %s", strerror(errno));
+	Error("[%s] ioctl(0,TIOCSETC): %s", pCE->server.string,
+	      strerror(errno));
 	exit(EX_UNAVAILABLE);
     }
     if (-1 == ioctl(0, TIOCGLTC, (char *)&m_ltchars)) {
-	Error("ioctl5: %s", strerror(errno));
+	Error("[%s] ioctl(0,TIOCGLTC): %s", pCE->server.string,
+	      strerror(errno));
 	exit(EX_UNAVAILABLE);
     }
     m_ltchars.t_werasc = '\027';
@@ -543,7 +558,8 @@ VirtDev(pCE)
     m_ltchars.t_suspc = '\032';
     m_ltchars.t_dsuspc = '\031';
     if (-1 == ioctl(0, TIOCSLTC, (char *)&m_ltchars)) {
-	Error("ioctl6: %s", strerror(errno));
+	Error("[%s] ioctl(0,TIOCSLTC): %s", pCE->server.string,
+	      strerror(errno));
 	exit(EX_UNAVAILABLE);
     }
 
@@ -560,13 +576,13 @@ VirtDev(pCE)
 # endif	/* HAVE_TERMIOS_H */
 
     close(2);
-    (void)dup(1);		/* better be 2, but it is too late now */
+    dup(1);			/* better be 2, but it is too late now */
 
     /* if the command is null we should run root's shell, directly
      * if we can't find root's shell run /bin/sh
      */
     pcShell = "/bin/sh";
-    if (pCE->pccmd.used == 0 || pCE->pccmd.string[0] == '\000') {
+    if (pCE->pccmd.used <= 1) {
 	static char *apcArgv[] = {
 	    "-shell", "-i", (char *)0
 	};
@@ -586,14 +602,14 @@ VirtDev(pCE)
 	ppcArgv = apcArgv;
     }
     execve(pcShell, ppcArgv, environ);
-    Error("execve: %s", strerror(errno));
+    Error("[%s] execve(): %s", pCE->server.string, strerror(errno));
     exit(EX_UNAVAILABLE);
 }
 
 /* down a console, virtual or real					(ksb)
  */
 void
-#if USE_ANSI_PROTO
+#if PROTOTYPES
 ConsDown(CONSENT * pCE, fd_set * pfdSet)
 #else
 ConsDown(pCE, pfdSet)
@@ -602,25 +618,26 @@ ConsDown(pCE, pfdSet)
 #endif
 {
     if (-1 != pCE->ipid) {
-	Debug(1, "Sending pid %d signal %d", pCE->ipid, SIGHUP);
+	Debug(1, "ConsDown(): sending pid %lu signal %d",
+	      (unsigned long)pCE->ipid, SIGHUP);
 	kill(pCE->ipid, SIGHUP);
 	pCE->ipid = -1;
     }
     if (-1 != pCE->fdtty) {
 	if ((fd_set *) 0 != pfdSet)
 	    FD_CLR(pCE->fdtty, pfdSet);
-	(void)close(pCE->fdtty);
+	close(pCE->fdtty);
 	pCE->fdtty = -1;
     }
     if ((CONSFILE *) 0 != pCE->fdlog) {
 	if (pCE->nolog) {
-	    filePrint(pCE->fdlog,
+	    FilePrint(pCE->fdlog,
 		      "[-- Console logging restored -- %s]\r\n",
-		      strtime(NULL));
+		      StrTime(NULL));
 	}
-	filePrint(pCE->fdlog, "[-- Console down -- %s]\r\n",
-		  strtime(NULL));
-	fileClose(&pCE->fdlog);
+	FilePrint(pCE->fdlog, "[-- Console down -- %s]\r\n",
+		  StrTime(NULL));
+	FileClose(&pCE->fdlog);
 	pCE->fdlog = (CONSFILE *) 0;
     }
     pCE->fup = 0;
@@ -629,7 +646,7 @@ ConsDown(pCE, pfdSet)
 }
 
 int
-#if USE_ANSI_PROTO
+#if PROTOTYPES
 CheckHostCache(const char *hostname)
 #else
 CheckHostCache(hostname)
@@ -648,7 +665,7 @@ CheckHostCache(hostname)
 }
 
 void
-#if USE_ANSI_PROTO
+#if PROTOTYPES
 AddHostCache(const char *hostname)
 #else
 AddHostCache(hostname)
@@ -658,16 +675,16 @@ AddHostCache(hostname)
     struct hostcache *n;
     if ((struct hostcache *)0 ==
 	(n = (struct hostcache *)calloc(1, sizeof(struct hostcache)))) {
-	Error("calloc failure: %s", strerror(errno));
+	Error("AddHostCache(): calloc(): %s", strerror(errno));
 	return;
     }
-    buildMyString(hostname, &n->hostname);
+    BuildString(hostname, &n->hostname);
     n->next = hostcachelist;
     hostcachelist = n;
 }
 
 void
-#if USE_ANSI_PROTO
+#if PROTOTYPES
 ClearHostCache(void)
 #else
 ClearHostCache()
@@ -690,7 +707,7 @@ ClearHostCache()
  * We also maintian the select set for the caller.
  */
 void
-#if USE_ANSI_PROTO
+#if PROTOTYPES
 ConsInit(CONSENT * pCE, fd_set * pfdSet, int useHostCache)
 #else
 ConsInit(pCE, pfdSet, useHostCache)
@@ -700,7 +717,7 @@ ConsInit(pCE, pfdSet, useHostCache)
 #endif
 {
     time_t tyme;
-#if USE_ANSI_PROTO
+#if PROTOTYPES
     extern int FallBack(STRING *, STRING *);
 #else
     extern int FallBack();
@@ -714,7 +731,7 @@ ConsInit(pCE, pfdSet, useHostCache)
     if (pCE->fup) {
 	ConsDown(pCE, pfdSet);
 	usleep(500000);		/* pause 0.50 sec to let things settle a bit */
-	resetMark();
+	ResetMark();
     }
 
     pCE->autoReUp = 0;
@@ -727,15 +744,17 @@ ConsInit(pCE, pfdSet, useHostCache)
      */
     if ((CONSFILE *) 0 ==
 	(pCE->fdlog =
-	 fileOpen(pCE->lfile.string, O_RDWR | O_CREAT | O_APPEND, 0644))) {
-	Error("open: %s: %s", pCE->lfile.string, strerror(errno));
+	 FileOpen(pCE->lfile.string, O_RDWR | O_CREAT | O_APPEND, 0644))) {
+	Error("[%s] FileOpen(%s): %s", pCE->server.string,
+	      pCE->lfile.string, strerror(errno));
 	return;
     }
-    filePrint(pCE->fdlog, "[-- Console up -- %s]\r\n", strtime(NULL));
+    FilePrint(pCE->fdlog, "[-- Console up -- %s]\r\n", StrTime(NULL));
 
     if (0 != pCE->fvirtual) {
 	if (-1 == (pCE->fdtty = FallBack(&pCE->acslave, &pCE->dfile))) {
-	    Error("Failed to allocate pseudo-tty: %s", strerror(errno));
+	    Error("[%s] failed to allocate pseudo-tty: %s",
+		  pCE->server.string, strerror(errno));
 	    ConsDown(pCE, pfdSet);
 	    return;
 	}
@@ -748,60 +767,63 @@ ConsInit(pCE, pfdSet, useHostCache)
 	struct timeval tv;
 
 	if (CheckHostCache(pCE->networkConsoleHost.string)) {
-	    Error("cached previous timeout: %s (%u@%s): forcing down",
-		  pCE->server.string, ntohs(port.sin_port),
-		  pCE->networkConsoleHost.string);
+	    Error("[%s] cached previous timeout: %s: forcing down",
+		  pCE->server.string, pCE->networkConsoleHost.string);
 	    ConsDown(pCE, pfdSet);
 	    return;
 	}
 	usleep(100000);		/* Not all terminal servers can keep up */
-	resetMark();
+	ResetMark();
 
 #if HAVE_MEMSET
-	(void)memset((void *)&port, 0, sizeof(port));
+	memset((void *)&port, 0, sizeof(port));
 #else
-	(void)bzero((char *)&port, sizeof(port));
+	bzero((char *)&port, sizeof(port));
 #endif
 
 	if ((hp = gethostbyname(pCE->networkConsoleHost.string)) == NULL) {
-	    Error("gethostbyname(%s): %s: forcing down",
-		  pCE->networkConsoleHost.string, hstrerror(h_errno));
+	    Error("[%s] gethostbyname(%s): %s: forcing down",
+		  pCE->server.string, pCE->networkConsoleHost.string,
+		  hstrerror(h_errno));
 	    ConsDown(pCE, pfdSet);
 	    return;
 	}
 #if HAVE_MEMCPY
-	(void)memcpy(&port.sin_addr.s_addr, hp->h_addr, hp->h_length);
+	memcpy(&port.sin_addr.s_addr, hp->h_addr, hp->h_length);
 #else
-	(void)bcopy(hp->h_addr, &port.sin_addr.s_addr, hp->h_length);
+	bcopy(hp->h_addr, &port.sin_addr.s_addr, hp->h_length);
 #endif
 	port.sin_family = hp->h_addrtype;
 	port.sin_port = htons(pCE->networkConsolePort);
 
 	if ((pCE->fdtty = socket(AF_INET, SOCK_STREAM, 0)) < 0) {
-	    Error("socket: %s", strerror(errno));
+	    Error("[%s] socket(AF_INET,SOCK_STREAM): %s",
+		  pCE->server.string, strerror(errno));
 	    exit(EX_UNAVAILABLE);
 	}
 	if (setsockopt
 	    (pCE->fdtty, SOL_SOCKET, SO_KEEPALIVE, (char *)&one,
 	     sizeof(one)) < 0) {
-	    Error("setsockopt SO_KEEPALIVE: %s", strerror(errno));
+	    Error("[%s] setsockopt(%u,SO_KEEPALIVE): %s",
+		  pCE->server.string, pCE->fdtty, strerror(errno));
 	}
 
 	if ((flags = fcntl(pCE->fdtty, F_GETFL)) >= 0) {
 	    flags |= O_NONBLOCK;
 	    if (fcntl(pCE->fdtty, F_SETFL, flags) < 0) {
-		Error("fcntl O_NONBLOCK: %s", strerror(errno));
+		Error("[%s] fcntl(%u,F_SETFL): %s", pCE->server.string,
+		      pCE->fdtty, strerror(errno));
 	    }
 	} else {
-	    Error("fcntl: %s", strerror(errno));
+	    Error("[%s] fcntl(%u,F_GETFL): %s", pCE->server.string,
+		  pCE->fdtty, strerror(errno));
 	}
 
 	if (connect(pCE->fdtty, (struct sockaddr *)&port, sizeof(port)) <
 	    0) {
 	    if (errno != EINPROGRESS) {
-		Error("connect: %s (%u@%s): %s: forcing down",
-		      pCE->server.string, ntohs(port.sin_port),
-		      pCE->networkConsoleHost.string, strerror(errno));
+		Error("[%s] connect(%u): %s: forcing down",
+		      pCE->server.string, pCE->fdtty, strerror(errno));
 		ConsDown(pCE, pfdSet);
 		return;
 	    }
@@ -813,17 +835,16 @@ ConsInit(pCE, pfdSet, useHostCache)
 	FD_SET(pCE->fdtty, &fds);
 
 	if ((one = select(pCE->fdtty + 1, NULL, &fds, NULL, &tv)) < 0) {
-	    Error("select: %s (%u@%s): %s: forcing down",
-		  pCE->server.string, ntohs(port.sin_port),
-		  pCE->networkConsoleHost.string, strerror(errno));
+	    Error("[%s] select(%u): %s: forcing down", pCE->server.string,
+		  pCE->fdtty, strerror(errno));
 	    ConsDown(pCE, pfdSet);
 	    return;
 	}
 
 	if (one == 0) {		/* Timeout */
 	    AddHostCache(pCE->networkConsoleHost.string);
-	    Error("timeout: %s (%u@%s): forcing down", pCE->server.string,
-		  ntohs(port.sin_port), pCE->networkConsoleHost.string);
+	    Error("[%s] connect timeout: forcing down", pCE->server.string,
+		  strerror(errno));
 	    ConsDown(pCE, pfdSet);
 	    return;
 	} else {		/* Response */
@@ -836,16 +857,14 @@ ConsInit(pCE, pfdSet, useHostCache)
 	    if (getsockopt
 		(pCE->fdtty, SOL_SOCKET, SO_ERROR, (char *)&flags,
 		 &slen) < 0) {
-		Error("getsockopt SO_ERROR: %s (%u@%s): %s: forcing down",
-		      pCE->server.string, ntohs(port.sin_port),
-		      pCE->networkConsoleHost.string, strerror(errno));
+		Error("[%s] getsockopt(%u,SO_ERROR): %s: forcing down",
+		      pCE->server.string, pCE->fdtty, strerror(errno));
 		ConsDown(pCE, pfdSet);
 		return;
 	    }
 	    if (flags != 0) {
-		Error("connect: %s (%u@%s): %s: forcing down",
-		      pCE->server.string, ntohs(port.sin_port),
-		      pCE->networkConsoleHost.string, strerror(flags));
+		Error("[%s] connect(%u): %s: forcing down",
+		      pCE->server.string, pCE->fdtty, strerror(flags));
 		ConsDown(pCE, pfdSet);
 		return;
 	    }
@@ -861,7 +880,8 @@ ConsInit(pCE, pfdSet, useHostCache)
     } else if (-1 ==
 	       (pCE->fdtty =
 		open(pCE->dfile.string, O_RDWR | O_NDELAY, 0600))) {
-	Error("open: %s: %s", pCE->dfile.string, strerror(errno));
+	Error("[%s] open(%s): %s", pCE->server.string, pCE->dfile.string,
+	      strerror(errno));
 	ConsDown(pCE, pfdSet);
 	return;
     }
